==> v-sim_3.3.3.orig.tar.gz: v_sim-3.3.3/src/panelModules/panelBrowser.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef PANELBROWSER_H
#define PANELBROWSER_H

#include <glib.h>
#include <gtk/gtk.h>

/**
 * BROWSER_PREVIOUS:
 *
 * Value that give the direction when the selector is moved around file list.
 * See panelBrowserGet_nextSelected().
 */
#define BROWSER_PREVIOUS 0
/**
 * BROWSER_NEXT:
 *
 * Value that give the direction when the selector is moved around file list.
 * See panelBrowserGet_nextSelected().
 */
#define BROWSER_NEXT     1

/**
 * panelBrowserGet_nextSelected:
 * @path: a pointer to returned the path of the newly selected file ;
 * @iterSelected: a pointer to store the newly selected iter ;
 * @direction: BROWSER_NEXT or BROWSER_PREVIOUS.
 *
 * Change the selected file in the browser given the direction.
 */
gboolean panelBrowserGet_nextSelected(GtkTreePath **path, GtkTreeIter *iterSelected, int direction);
/**
 * panelBrowserGet_currentSelected:
 * @path: a pointer to returned the path of the currently selected file ;
 * @iterSelected: a pointer to store the currently selected iter.
 *
 * Get iter and path of the currently sleected file.
 */
gboolean panelBrowserGet_currentSelected(GtkTreePath **path, GtkTreeIter *iterSelected);

#endif

==> v-sim_3.5.1.orig.tar.gz: v_sim-3.5.1/src/panelModules/panelBrowser.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#ifndef PANELBROWSER_H
#define PANELBROWSER_H

#include <glib.h>
#include <gtk/gtk.h>

#include <extraGtkFunctions/gtk_toolPanelWidget.h>

/**
 * BROWSER_PREVIOUS:
 *
 * Value that give the direction when the selector is moved around file list.
 * See panelBrowserGet_nextSelected().
 */
#define BROWSER_PREVIOUS 0
/**
 * BROWSER_NEXT:
 *
 * Value that give the direction when the selector is moved around file list.
 * See panelBrowserGet_nextSelected().
 */
#define BROWSER_NEXT     1

/**
 * panelBrowser_init:
 *
 * Should be used in the list declared in externalModules.h to be loaded by
 * V_Sim on start-up. This routine will create the #ToolPanel handling
 * the browser.
 *
 * Returns: a newly created #ToolPanel object.
 */
ToolPanel* panelBrowser_init();

/**
 * panelBrowserGet_nextSelected:
 * @path: a pointer to returned the path of the newly selected file ;
 * @iterSelected: a pointer to store the newly selected iter ;
 * @direction: BROWSER_NEXT or BROWSER_PREVIOUS.
 *
 * Change the selected file in the browser given the direction.
 *
 * Returns: TRUE if one exists.
 */
gboolean panelBrowserGet_nextSelected(GtkTreePath **path,
				      GtkTreeIter *iterSelected, int direction);
/**
 * panelBrowserGet_currentSelected:
 * @path: a pointer to returned the path of the currently selected file ;
 * @iterSelected: a pointer to store the currently selected iter.
 *
 * Get iter and path of the currently sleected file.
 *
 * Returns: TRUE if one exists.
 */
gboolean panelBrowserGet_currentSelected(GtkTreePath **path,
					 GtkTreeIter *iterSelected);
/**
 * panelBrowserSet_currentDirectory:
 * @dir: the path of a directory.
 *
 * Change the directory for the browser. The directory is not parsed immediately
 * but only when the subpanel becomes visible.
 */
void panelBrowserSet_currentDirectory(const gchar *dir);
/**
 * panelBrowserSet_currentDirectories:
 * @dirs: a NULL terminated array of directories to be loaded.
 *
 * Change the directories for the browser. It is the same routine than 
 * panelBrowserSet_currentDirectory(), but several directories can be loaded
 * at once. But internally, contrary to panelBrowserSet_currentDirectory()
 * the given array must not be freed since it is not copied.
 */
void panelBrowserSet_currentDirectories(gchar **dirs);

#endif
